@@ -2,6 +2,7 @@ import os
 from datetime import date
 from pathlib import Path
 import webbrowser
+import platform
 
 import click
 
@@ -14,9 +15,16 @@ from .directory import get_images
 from .mv import create_mv_folder
 from .functions import get_client_and_project, get_date, get_project_number
 
-font_dir = Path('X:/9999_BID_AMS/AMS-VFB_Fonts')
+font_path = "9999_BID_AMS/AMS-VFB_Fonts"
+
+logo_path = "9999_BID_AMS/AMS_Logo's/RGB/Animotions_Logo_02_RGB.png"
+
+proj_dir_windows = "X:"
+proj_dir_macos = "/Volumes/ams-fileserver/"
+
+dir = Path(proj_dir_windows) if platform.system(
+) == "Windows" else Path(proj_dir_macos)
 
-logo = "X:/9999_BID_AMS/AMS_Logo's/RGB/Animotions_Logo_02_RGB.png"
 
 frame_width = 200
 frame_height = 170
@@ -36,6 +44,8 @@ def get_cwd():
 
 
 def main():
+    logo = dir.joinpath(logo_path)
+    font_dir = dir.joinpath(font_path)
     click.echo(f"🥰 Let's create a briefing {os.getlogin()}!")
     pdf = FPDF(orientation='L', format='A4')
     pdf.set_author('Animotions')
@@ -94,7 +104,8 @@ def main():
         if height > width:
             ratio = height/frame_height
             ratio_x = width/ratio
-            pdf.image(str(f), x=80+(frame_width - ratio_x)/2, h=frame_height)
+            pdf.image(str(f), x=80+(frame_width - ratio_x) /
+                      2, y=15, h=frame_height)
 
     mv_dir = create_mv_folder(project_path, verbose=True)
 
